pub  mod inlineops;
     mod sliceops;
     mod muldiv;
     mod conversion;
     
 pub mod sign;
 pub mod mpz;
 pub mod mpz_ent;   
